
#include "LedControl.h"  //  need the library
#include "math.h"
#include "Quadrature.h"
#include "binary.h"      // must be included

 

//VCC, GND, DOUT, LOAD, CLK. On 7219 Module.
// LedControl(Data,Clock,Load,Displays)


LedControl led_Display_1 = LedControl(18,16,17,8);
int CodeIn;// used on all serial reads
String Digit;      // 
int Count;


int NumberOfButtons = 11; // Change if more buttons added

struct BUTTON
{
  const byte pin;
  bool State;               // not used
  bool lastState; 
  bool Pressed;
  bool longPressLast;       // not used
  bool longPressActive;
  bool buttonActive;        // not used
  byte counter;             // not used
};

// array of information relevant to buttons( Structure = Pin Number, State, LastState, Pressed, Counter,Squawk) 
BUTTON buttons[] =
{                                                      //Array No.
  {65, false, false,false,false,false,false,0},         //0 Button         0
  {12, false, false,false,false,false,false,0},         //1 Button         1
  
  {8, false, false,false,false,false,false,0},         //2 Button          2
  {1, false, false,false,false,false,false,0},         //3 Button          3
  
  {0, false, false,false,false,false,false,0},         //4 Button          4
  {14, false, false,false,false,false,false,0},        //5 Button          5

  {7, false, false,false,false,false,false,0},         //6 Button          6
  {6, false, false,false,false,false,false,0},         //7 Button          7
  
  {5, false, false,false,false,false,false,0},         //CLR  Button       8
  {15, false, false,false,false,false,false,0},        //VFR Button        9
  {56, false, false,false,false,false,false,0},        //IDT Button       10
};

int Battery[2];                // Battery On/Off
//int Battery[]= {0,1};         // Battery On/Off  (For Testing)
int Avionics[2];              // Avionics On/Off
//int Avionics[2]= {0,1};        // Avionics On/Off (For Testing)
int VFR[]= {1,2,0,0};         // Set Defaut VFR CODE for VFR Button 1200, can be anything.
int Squawk_code[4];           // the Simulator Squawk code is entered in this array,
char Last_Squawk_code[4];     // Squawk Code in memory for recall on holding VFR button for 2 seconds

int entered[4];               // create a new empty array for the 4 digit code entered by the user
int Flight_Level[3];          // Flight Level received from the Simualtor
int B_Counter = 0;            // Counts the digits entered into the Code display up to 4 digits
int XPDR_pin = A1;            // Analog Pin used by the potentiometer


//Used for debouncing all button pushes

const unsigned long longPressThreshold = 1500; // the threshold (in milliseconds) before a long press is detected. VFR revert to last squawk code
const unsigned long debounceThreshold = 75; // the threshold (in milliseconds) for a button press to be confirmed (i.e. not "noise")

unsigned long buttonTimer = 0; // stores the time that the button was pressed (relative to boot time)
unsigned long buttonPressDuration = 0; // stores the duration (in milliseconds) that the button was pressed/held down for
 




//There is a timer used to Time the display between the push buttons. Set at 4 Seconds.
//The last active code will be displayed if a complete four-digit code has not been
//entered and there is no activity on any of the code entry buttonss, the VFR
//button, or the CLR button for four seconds. 
 
long currentMillis = 0;
long startMillis;                 // Start Timer on Button pressed
const long period = 4000;         // Time to wait after each Button Press (As per Bendix manual)
long IDT_startMillis;             // IDT Start Timer on Button pressed
const long IDT_Period = 18000;    // Time to display "R" after IDT Button Pushed (As per Bendix manual)
long PotpreviousMillis = 0;       // Debounce time for turning the Potentiometer

//const long VFR_period = 2000;

bool TimerOn = false;           // 4 Second Timer Flag On_Off
bool IDT_TimerOn = false;       // 18 Second Timer Flag On_Off
bool VFR_Last_Squawk = false;   // VFR buton pushed for 2 Secs, the flag to revert to Last_Squawk_Code used.
bool SendCode = false;          // After 4 seconds and 4 digits updated, ok to send Squawk to the simulator
bool VFR_On = false;            // VFR Mode Overrides all code immediately
//bool Last_Active_Code = false; ///  not used

enum {                           // The state of the Potentiometer as it turns
  Off,
  STBY,
  Test,
  On,
  Alt
}Knob_Select;

int XPDR_Rotary_percent_old = 0;



void setup(){ //run once at sketch startup

  // Start serial debugging
  Serial.begin(115200);

  //The MAX72XX is in power-saving mode on startup, we have to do a wakeup call
  delay (500);
  led_Display_1.shutdown(0,false);      // I have 4 displays, these start them up
  delay (500);                          // I put the delay in so they all dont start drawing
  led_Display_1.shutdown(1,false);      // current at the same time.
  delay (500);                          // I had an issue with running on only USB power and getting a display glitch.
  



  // Set the brightness to a lower than medium values 
  led_Display_1.setIntensity(0,4);
  led_Display_1.setIntensity(1,4);
  delay (500);

 
  // and clear the display 
  led_Display_1.clearDisplay(0);
  led_Display_1.clearDisplay(1);
  

   for (int i = 0; i < NumberOfButtons; i++)
  {
    pinMode(buttons[i].pin, INPUT_PULLUP);   //Button are "on" when Low/(Pushed)
  }
 
 
 }


void Code_DISPLAY(){          

long Av = Avionics[1];
long Bat = Battery[1];

if ((Av == 1) && (Bat == 1) ){   // Is the Battery, Avionics and the Transponder unit turned "On"? Then display...
  
   if ((Knob_Select == Off))
           { 
           led_Display_1.setChar (0,0,' ',false);  //Off LED Digits 
           led_Display_1.setChar (0,1,' ',false);
           led_Display_1.setChar (0,2,' ',false);
           led_Display_1.setChar (0,3,' ',false);
           }

//)
     else if ((Knob_Select == Test))
           { 
           led_Display_1.setDigit (0,0,8,false);  //Test LED Digits all on
           led_Display_1.setDigit (0,1,8,false);
           led_Display_1.setDigit (0,2,8,false);
           led_Display_1.setDigit (0,3,8,false);
           //led_Display_1.setRow(0,7,231);
           }
   
   
   else if ((TimerOn == true) && (B_Counter == 1))
           { 
           led_Display_1.setDigit(0,0,entered[0],false);  //IDENT CODE 1st digit entered
           led_Display_1. setChar (0,1,'-',false);
           led_Display_1. setChar (0,2,'-',false);
           led_Display_1. setChar (0,3,'-',false);
           }

   else if ((TimerOn == true) && (B_Counter == 2))
           { 
           led_Display_1.setDigit(0,0,entered[0],false);  //IDENT CODE 2nd digit entered
           led_Display_1.setDigit(0,1,entered[1],false);
           led_Display_1. setChar (0,2,'-',false);
           led_Display_1. setChar (0,3,'-',false);
           }

    else if ((TimerOn == true) && (B_Counter == 3))
           { 
           led_Display_1.setDigit(0,0,entered[0],false);  //IDENT CODE 3rd digit entered
           led_Display_1.setDigit(0,1,entered[1],false);
           led_Display_1.setDigit(0,2,entered[2],false);
           led_Display_1. setChar (0,3,'-',false);
           }  

     else if ((TimerOn == true) && (B_Counter == 4) )
           {
           led_Display_1.setDigit(0,0,entered[0],false);  //IDENT entered CODE on display until 4 seconds timer elapses
           led_Display_1.setDigit(0,1,entered[1],false);
           led_Display_1.setDigit(0,2,entered[2],false);
           led_Display_1.setDigit(0,3,entered[3],false);
     }      
                
      else if ((TimerOn == false)&&(VFR_On == false))         //check that the VFR Code and Timer not in use
           { 

           led_Display_1.setDigit(0,0,Squawk_code[0],false);  //IDENT 4 Digits now the simulator Squawk CODE
           led_Display_1.setDigit(0,1,Squawk_code[1],false);
           led_Display_1.setDigit(0,2,Squawk_code[2],false);
           led_Display_1.setDigit(0,3,Squawk_code[3],false);
           
           B_Counter = 0;                                     //resets the Button Counter and the Entered Code Array for next time

           }




      else if ((TimerOn == false)&&(VFR_On == true)&&(VFR_Last_Squawk == false))
           { 
           led_Display_1.setDigit(0,0,VFR[0],false);  //IDENT VFR CODE if the VFR Button is pushed and it replaces the Squawk Code
           led_Display_1.setDigit(0,1,VFR[1],false);
           led_Display_1.setDigit(0,2,VFR[2],false);
           led_Display_1.setDigit(0,3,VFR[3],false);
           B_Counter = 0;                             //resets the Button Counter and the Entered Code Array for next time
      
           }

      else if ((TimerOn == false)&&(VFR_On == true)&&(VFR_Last_Squawk == true)) // if VFR button pushed for 2 Secs, the flag to revert to Last_Squawk_Code used.
           { 

           led_Display_1.setDigit(0,0,Last_Squawk_code[0],false);  //IDENT FSX Last Squawk CODE
          // Serial.print("Last_Squawk_code[0] Display ");Serial.println(Last_Squawk_code[0]);
           led_Display_1.setDigit(0,1,Last_Squawk_code[1],false);
           led_Display_1.setDigit(0,2,Last_Squawk_code[2],false);
           led_Display_1.setDigit(0,3,Last_Squawk_code[3],false);
           
           }
                 
}
}

void FL_DISPLAY(){ //checks the status of the Knob Selction and display as indicated

long Av = Avionics[1];
long Bat = Battery[1];

if ((Av == 1) && (Bat == 1)){   // Is the Battery & Avionics "On"?
  
   switch(Knob_Select){   // Update the Display depending on knob selction off, STBY, Test,On , Alt
   case 0: //Off
          
           led_Display_1. setChar (0,4,' ',false);  //Flight Level is blank when off
           led_Display_1. setChar (0,5,' ',false);
           led_Display_1. setChar (0,6,' ',false);
     break;
     
    case 1:  //STBY
           
           led_Display_1. setChar (0,4,' ',false);  //Flight Level is blank when STBY
           led_Display_1. setChar (0,5,' ',false);
           led_Display_1. setChar (0,6,' ',false);

          break;
          
   case 2: //Test
          
           led_Display_1.setDigit (0,4,8,false);  //Flight Level is 888 when Test
           led_Display_1.setDigit (0,5,8,false);
           led_Display_1.setDigit (0,6,8,false);
          
          break;
          
    case 3: //On
          
           led_Display_1. setChar (0,4,' ',false);  //Flight Level is Blank when On
           led_Display_1. setChar (0,5,' ',false);
           led_Display_1. setChar (0,6,' ',false);
          
          break;
              
    case 4: //Alt
          
           led_Display_1.setDigit (0,4,Flight_Level[0],false);  //Flight Level  is shown when ALT
           led_Display_1.setDigit (0,5,Flight_Level[1],false);
           led_Display_1.setDigit (0,6,Flight_Level[2],false);
          
          break;
   }                   
}
}

void loop(){ //run repeatedly

Debounce_Buttons();       //Debounces all Button pushes
Code_DISPLAY();           //Displays the button pushes
FL_DISPLAY();             //Displays the Flight Level depending on the Mode   
XPDR_Rotary();            //The potentiometer and the Mode selction

  if (Serial.available()) {// Check if serial data has arrived from PC
    CodeIn = getChar();
   if (CodeIn == '=') {EQUALS();} // The first identifier is "="
  }
  

currentMillis = millis();

//This tests whether Button Timer period to input or change a INDENT Code has elapsed or not.
if ((TimerOn == true)&&(currentMillis - startMillis >= period))  
          {
            TimerOn = false;  
            //Serial.println ("4 Sec Timer Finished");//For Testing only
            SendCode= true;
          }
            
// Sends the new entered Sqauwk Code to FSX only after all 4 digits are entered and after the 4 Seconds timer has elapsed.  
          
   if ((SendCode == true)&& (B_Counter == 4) )                ///&& (VFR_Last_Squawk == true)
        {       
            long XPNDR=0;          //Loads the 4 Entered Digits from the array into a number to send as a Serial "TRxxxx" to Simulator
            for(int i=0; i<4; i++)
            {
              XPNDR *= 10;
              XPNDR += entered[i];
            }
            
           Serial.print("TR");Serial.println(XPNDR);     //New Squawk Code sent to the simulator
          
          //  Serial.print(VFR_Last_Squawk);
          
          Squawk_code[0] = entered[0];        //4 digit Codes entered bencomes the Squawk_Code and the Last_Squawk_Code
          Squawk_code[1] = entered[1];
          Squawk_code[2] = entered[2];
          Squawk_code[3] = entered[3];

          Last_Squawk_code[0] = Squawk_code[0];
          Last_Squawk_code[1] = Squawk_code[1];
          Last_Squawk_code[2] = Squawk_code[2];
          Last_Squawk_code[3] = Squawk_code[3];

          
          
          //Serial.print(Squawk_code[0]); Serial.print(Squawk_code[1]); Serial.print(Squawk_code[2]); Serial.println(Squawk_code[3]);
               
         SendCode = false;  //Once the new Indent Code is sent to the simulator, it won't do it agin until a new code is keyed.
         }



  if ((SendCode == true)&& (VFR_Last_Squawk == true))  // if VFR buton pushed for 2 Secs, the display reverts to Last_Squawk_Code used.
        {       
            long XPNDR=0;           //Loads the 4 Entered Digits from the array into a number to send as a Serial "TRxxxx" to the sim
            for(int i=0; i<4; i++)
            {
              XPNDR *= 10;
              XPNDR += Last_Squawk_code[i];
            }
            
            Serial.print("TR");Serial.println(XPNDR); //Last Squawk Code sent to the simulator after VFR Button held for 2 secs
                    
          
          //Serial.print(Squawk_code[0]); Serial.print(Squawk_code[1]); Serial.print(Squawk_code[2]); Serial.println(Squawk_code[3]);
               
         SendCode = false;
         }


  //sets up the analog read delay so that there is less noise in the reading.
  
  unsigned long currentPotMillis = millis();
  if(currentPotMillis - PotpreviousMillis > 200) {  // change the 200 to suit time delay/speed
  PotpreviousMillis = currentPotMillis;
  }


//This tests whether the 18 Second Period after IDT Button pushed has elapsed or not and turns the "R" led off.

if ((IDT_TimerOn == true) && ((currentMillis - IDT_startMillis) >= IDT_Period)){ //Stop the IDT Button Timer after 18 Seconds.
            IDT_TimerOn = false;
            }
         
}

char getChar()// Get a character from the serial buffer
{
  while(Serial.available() == 0);// wait for data
  return((char)Serial.read());// Thanks Doug
}

void Debounce_Buttons() {   //debounces all push buttons

  for (int i = 0; i < NumberOfButtons; i++)
  {
  int reading = digitalRead(buttons[i].pin);
  if (reading == LOW)
  
    {
                 // mark the button as active, and start the timer
                  if (buttons[i].Pressed == false )
                 
                    { 
                    buttons[i].Pressed = true;
                    buttonTimer = millis();
                    }

          // calculate the button press duration by subtracting the button time from the Arduino time
          buttonPressDuration = millis() - buttonTimer;


 
                 // mark the button as long-pressed if the button press duration exceeds the long press threshold
                 
                        if ((buttonPressDuration > longPressThreshold) && (buttons[i].longPressActive == false))
                            {
                              
                           // if VFR buton pushed for 2 Secs, the display reverts to Last_Squawk_Code used as per the Bendix manual.
                           
                              buttons[i].longPressActive = true;  
                              VFR_Last_Squawk = true;     //Sets the Last_Squawk_Code flag 
                              SendCode= true;//
                            }
    
                           

}//End If

// button either hasn't been pressed, or has been released
else
{
                 // if the button was marked as active, it was recently pressed
                  if (buttons[i].Pressed == true)
                    {
                    // reset the long press active state
                        if (buttons[i].longPressActive == true)
                        {
                          buttons[i].longPressActive = false;
                        }

                        // we either need to debounce the press (noise) or register a normal/short press
                        else
                        {
                        // if the button press duration exceeds our bounce threshold, then we register a short press
                             if (buttonPressDuration > debounceThreshold)
                               {
                                buttons[i].Pressed = true;
                                Button_actions(); // A valid button press will activate the various Button Actions
                                }
                        }
                    
                    // resets the button active status
                     buttons[i].Pressed = false;
                        }
                    
                                  
}//End else

buttons[i].lastState = reading;

  }
}//End Void


                             

void Button_actions(){

  for (int i = 0; i < NumberOfButtons; i++){
    if (buttons[i].Pressed) {            // If the button is pressed then....

    startMillis = currentMillis;        //Start the Button Timer when any button is pushed.
    TimerOn = true;
    VFR_On = false;
    //Serial.println ("4 Sec Timer Started");Serial.print ("Last State=: ");Serial.println (buttons[i].lastState);//For Testing only

  if (buttons[0].Pressed == true){ //if button0 is pressed
   
    if (B_Counter >= 4){B_Counter = 4;}
    else B_Counter++;
    DigitEntered1(0); //call DigitEntered and pass it a 0 
    buttons[0].Pressed == false;  
  }

  else if (buttons[1].Pressed == true){ //if button1 is pressed
    if (B_Counter >= 4){B_Counter = 4;}
    else B_Counter++;
    DigitEntered1(1); //call DigitEntered1 and pass it a 1

  }
    else if (buttons[2].Pressed == true){ //if button1 is pressed
     
      if (B_Counter >= 4){B_Counter = 4;}
    else B_Counter++;
    DigitEntered1(2); //call DigitEntered1 and pass it a 2
 
  }
  else if (buttons[3].Pressed == true){ //if button1 is pressed
    
        if (B_Counter >= 4){B_Counter = 4;}
    else B_Counter++;
    DigitEntered1(3); //call DigitEntered1 and pass it a 3

  }

  //else if (digitalRead(buttons[4].pin) == LOW){ //if button4 is pressed
   else if (buttons[4].Pressed == true){ //if button1 is pressed
    
      if (B_Counter >= 4){B_Counter = 4;}
    else B_Counter++;
    DigitEntered1(4); //call DigitEntered1 and pass it a 4
  }

  else if (buttons[5].Pressed == true){ //if button1 is pressed
   
    if (B_Counter >= 4){B_Counter = 4;}
    else B_Counter++;
    DigitEntered1(5); //call DigitEntered1 and pass it a 5
  }

  else if (buttons[6].Pressed == true){ //if button1 is pressed
   
    if (B_Counter >= 4){B_Counter = 4;}
    else B_Counter++;
    DigitEntered1(6); //call DigitEntered1 and pass it a 6
  }


else if (buttons[7].Pressed == true){ //if button1 is pressed 
 
       if (B_Counter >= 4){B_Counter = 4;}
    else B_Counter++;
    DigitEntered1(7); //call DigitEntered1 and pass it a 7
   

  }

  else if (buttons[8].Pressed == true){ //if button1 is pressed
    if (B_Counter <= 0){B_Counter = 0;}
    else B_Counter--;

  }


  else if (buttons[9].Pressed == true){ //if button 8 is pressed  

     TimerOn = false; //VFR stops the 4 second input timer
     VFR_On = true;   //VFR Code immediately set to display and FSX.
     VFR_Last_Squawk = false; //Last_Squawk display flag reset.
     
            long VFRCODE=0;
            for(int i=0; i<4; i++)
            {
              VFRCODE *= 10;
              VFRCODE += VFR[i];
            }
            Serial.print("TR");Serial.println(VFRCODE);
            //Serial.print(VFR_Last_Squawk); 

              
  }


  else if (buttons[10].Pressed == true){ //if IDT button is pressed  
    
     IDT_startMillis = currentMillis;        //Start the IDT Button Timer when IDT button is pushed.
     IDT_TimerOn = true; //Starts IDT 18 second timer       
  }

  
  buttons[i].Pressed =false; //reset the button
  }
 } 
}
  




void DigitEntered1(int button){ //check the first element of the entered[] array

 if (B_Counter==1){ entered[0] = button; 
  }
  else if(B_Counter>=2){ //if it is zero, i.e. if it hasn't been defined with a button yet
    DigitEntered2(button); //set the first element as the button that has been pressed
  }
 }

void DigitEntered2(int button){ //check the second element of the entered[] array

 if (B_Counter==2){ entered[1] = button; 
   }
  else if(B_Counter>=3){ //if it is zero, i.e. if it hasn't been defined with a button yet
    DigitEntered3(button); //set the first element as the button that has been pressed
  }
 }

void DigitEntered3(int button){  //check the third element of the entered[] array
 
 if (B_Counter==3){ 
  entered[2] = button; 
 }
  else if(B_Counter==4){ //if it is zero, i.e. if it hasn't been defined with a button yet
    DigitEntered4(button); //set the first element as the button that has been pressed
  }
 }

void DigitEntered4(int button){  //check the third element of the entered[] array

 if (B_Counter>=4){ 
  entered[3] = button; 
  B_Counter=4;
   }
 }

void EQUALS()               // The first identifier was "=" Receives information from Lua/FSX for each Button Press
{  
    CodeIn = getChar();     // Get another character
    switch(CodeIn)          // Now lets find what to do with it
    {

            case 'A':     //Avionics
        Count = 0;
        while (Count < 2 )
        {
          Digit = "";
          Digit += getChar();
          Avionics[Count] = Digit.toInt();
          Count++;
        }
    break;

            case 'B':     //Battery
        Count = 0;
        while (Count < 2 )
        {
          Digit = "";
          Digit += getChar();
          Battery[Count] = Digit.toInt();
          Count++;
        }
    break;

        case 'F':     //Flight Level
        Count = 0;
        while (Count < 4 )
        {
          Digit = "";
          Digit += getChar();
          Flight_Level[Count] = Digit.toInt();
          Count++;
        }
    break;
        
        case 'T':     //FSX/Simulator Squawk_code
        Count = 0;
        while (Count < 5 )
        {
          Digit = "";
          Digit += getChar();
          if (Digit ==".")
            {
              Digit = "";
              Digit += getChar();
            }
          Squawk_code[Count] = Digit.toInt();
          Count++;
        }
    break;


            
    

    } // ***  End of Switch Case ***
}
//***************( End of Slash() Function )**************

void XPDR_Rotary(){
  
int firstReadT, XPDR_Rotary_percent;
int XPDR_Rotary_oldPercent;
firstReadT = analogRead(XPDR_pin);

XPDR_Rotary_percent = map(firstReadT, 0, 1023, 0, 100);

if ((XPDR_Rotary_percent + 2 < XPDR_Rotary_oldPercent) || (XPDR_Rotary_percent - 2 > XPDR_Rotary_oldPercent)){
  String tempString = String(XPDR_Rotary_percent);
  while (tempString.length() < 3) tempString = '0' + tempString;
        
        if((XPDR_Rotary_percent >0)&& (XPDR_Rotary_percent < 7)){
                   
            led_Display_1.setRow(0,7,0); //   All Leds Off See https://wayoda.github.io/LedControl/pages/software for explanation (Binary Led)

                if (abs(XPDR_Rotary_percent- XPDR_Rotary_percent_old)>5){
                  Knob_Select= Off;
                  Serial.println("Off");
                  XPDR_Rotary_percent_old = XPDR_Rotary_percent;
                  }
            }
          
            
        else if((XPDR_Rotary_percent > 10)&& (XPDR_Rotary_percent < 25)){ 

        // I have used the last Digit of the MAX7219 to use to turn on/off all the LEDS needed.
        // Transponder LEDS
        //          [SBY]     [R]    [ON]                 [GND]  [FL]     [ALT}
        //           DP      SeG A   Seg B  Seg C  Seg D  Seg E  Seg F    Seg G
        //Bit-Value 128       64      32     16     8      4      2        1
        
        //Example
        //Led On?   Yes       Yes     Yes    No     No      No    Yes      No
        //Row-Value 128       64       32    16      0      0       2       0
        //value=226 (128+64+32+2)


                if ((IDT_TimerOn == true)){led_Display_1.setRow(0,7,192);} //SBY = 128, R = 64
                else{
                  led_Display_1.setRow(0,7,128); // SBY Led   See https://wayoda.github.io/LedControl/pages/software for explanation (Binary Led)
                  }
                if (abs(XPDR_Rotary_percent- XPDR_Rotary_percent_old)>6){
                  Knob_Select = STBY;
                  Serial.println("STBY");
                  XPDR_Rotary_percent_old = XPDR_Rotary_percent;
                  
                  }

            }

            
        else if((XPDR_Rotary_percent > 35) && (XPDR_Rotary_percent < 45))
            
            {             
                       
                  led_Display_1.setRow(0,7,231); // FL ALT ON GND R SBY Leds   See https://wayoda.github.io/LedControl/pages/software for explanation (Binary Led)
                  if (abs(XPDR_Rotary_percent- XPDR_Rotary_percent_old)>5){
                  Knob_Select = Test; Serial.println("Test");
                  XPDR_Rotary_percent_old = XPDR_Rotary_percent;
                  
                  }
              
             }
            
        else if((XPDR_Rotary_percent > 50) && (XPDR_Rotary_percent < 70))
         
                   {

                if ((IDT_TimerOn == true)){led_Display_1.setRow(0,7,96);} //ON = 32, R = 64
                else{
                  led_Display_1.setRow(0,7,32); // ON Led   See https://wayoda.github.io/LedControl/pages/software for explanation (Binary Led)
                  }

                    
              
                 // led_Display_1.setRow(0,7,32); // ON Led   See https://wayoda.github.io/LedControl/pages/software for explanation (Binary Led)
                  if (abs(XPDR_Rotary_percent- XPDR_Rotary_percent_old)>5){
                      Knob_Select = On;Serial.println("On");
                      XPDR_Rotary_percent_old = XPDR_Rotary_percent;
                      }
              
                  }
            
        else if(XPDR_Rotary_percent > 75)

                  {


                  if ((IDT_TimerOn == true)){led_Display_1.setRow(0,7,67);} //ALT = 1 , FL = 2, R = 64
                else{
                  led_Display_1.setRow(0,7,3); // ON Led   See https://wayoda.github.io/LedControl/pages/software for explanation (Binary Led)
                  }

                    
                  //led_Display_1.setRow(0,7,3); // FL and ALT Leds
                  if (abs(XPDR_Rotary_percent- XPDR_Rotary_percent_old)>5){
                  Knob_Select = Alt;Serial.println("ALT");
                  XPDR_Rotary_percent_old = XPDR_Rotary_percent;
                  
                  }
              
              
              
  }
}
}
